**Open Access Journal of Sports Medicine** **Dovepress**

open access to scientific and medical research

Open Access Full Text Article

R e v i e w

# An evidence-based review of hip-focused neuromuscular exercise interventions to address dynamic lower extremity valgus

This article was published in the following Dove Press journal:
Open Access Journal of Sports Medicine
25 August 2015

Number of times this article has been viewed

Kevin R Ford \[1\]

Anh-Dung Nguyen \[2\]

Steven L Dischiavi \[1\]

Eric J Hegedus \[1\]

Emma F Zuk \[2\]

Jeffrey B Taylor \[1\]

1Department of Physical Therapy,
High Point University, High Point, NC,
USA; \[2\] Department of Athletic Training,
School of Health Sciences, High Point
University, High Point, NC, USA

Correspondence: Kevin R Ford
Department of Physical Therapy, High
Point University, 833 Montlieu Avenue,
High Point, NC 27268, USA
Tel + 1 336 841 9495

Fax + 1 336 888 5020
[Email kford@highpoint.edu](mailto:kford@highpoint.edu)

**Abstract:** Deficits in proximal hip strength or neuromuscular control may lead to dynamic

lower extremity valgus. Measures of dynamic lower extremity valgus have been previously
shown to relate to increased risk of several knee pathologies, specifically anterior cruciate

ligament ruptures and patellofemoral pain. Therefore, hip-focused interventions have gained

considerable attention and been successful in addressing these knee pathologies. The purpose

of the review was to identify and discuss hip-focused exercise interventions that aim to address

dynamic lower extremity valgus. Previous electromyography, kinematics, and kinetics research

support the use of targeted hip exercises with non-weight-bearing, controlled weight-bearing,

functional exercise, and, to a lesser extent, dynamic exercises in reducing dynamic lower extrem­

ity valgus. Further studies should be developed to identify and understand the mechanistic

relationship between optimized biomechanics during sports and hip-focused neuromuscular

exercise interventions.

**Keywords:** dynamic lower extremity valgus, hip neuromuscular control, ACL injury rehabilita­

tion, patellofemoral pain, hip muscular activation

## **Introduction**

Hip-focused neuromuscular exercise interventions have gained considerable attention

for addressing a myriad of lower extremity injuries. Most notably, anterior cruciate

ligament (ACL) ruptures and patellofemoral pain (PFP) are two knee pathologies that
may benefit from improved proximal strength and neuromuscular control strategies. \[1\]
Deficits in proximal hip strength or neuromuscular control may lead to dynamic
lower extremity valgus. \[2\] Dynamic lower extremity valgus is operationally defined

as a combination of motions and rotations in the lower extremity, including hip

adduction and internal rotation, knee abduction, tibial external rotation and anterior

translation, and ankle eversion. \[3\] During sport movements, dynamic lower extremity

valgus often presents as a knocked-knee posture during deceleration during double leg

and single leg tasks (Figure 1). Importantly, knee abduction moment, which directly
contributes to dynamic lower extremity valgus, was a significant predictor for future
ACL injury risk with 73% sensitivity and 78% specificity in a prospective study of
young female athletes. \[2\] Frontal plane knee motion was predictive, along with hip

internal/external rotation moment, of second ACL injury risk in young athletes who
returned to their previous sport following reconstructive surgery and rehabilitation. \[4\]
Additionally, a recent investigation identified that high knee abduction moment was
predictive of both PFP and ACL injury risk in young female athletes. \[5\]

Ford et al

**Dovepress**

**Figure 1** Dynamic lower extremity valgus.
**Notes:** ( **A** ) Athlete lands during a double leg drop vertical jump at initial contact and ( **B** ) immediately displays dynamic lower extremity valgus on both legs. ( **C** ) Athlete lands
during a single leg hop and ( **D** ) exhibits dynamic lower extremity valgus on the right leg.

Sex differences in the incidence of both PFP and non-­contact

ACL injury have led to a plethora of comparisons between

males and females, indicating that the higher incidence of

these two pathologies in females may be due to faulty lower

extremity biomechanics and hip weakness. ­Biomechanically,

it has been widely reported that females exhibit increased

lower extremity valgus alignment and load compared with
males during landing and pivoting movements, \[6–18\] which
was confirmed in a recent systematic review that consis­

tently identified that females land with increased knee
abduction across a variety of landing conditions. \[19\] Similar

lower ­extremity valgus alignments are often demonstrated
by females at the time of ACL injury. \[20–22\]

Additionally, males have longitudinal increases in hip

strength during adolescent growth compared with no strength
changes in females. \[23\] The result of these sex differences fol­

lowing growth and development is that males have greater
overall hip strength compared with females. \[23\] This strength
difference aligns with the divergent sex-specific patterns of

ACL and patellofemoral joint injury rates. Competitive, colle­
giate male cross-country runners exhibit significantly greater

hip extension and abduction strength measured isokinetically
compared with female runners. \[24\] ­Additionally, runners with

lower hip abductor and hip extensor strength exhibit greater
frontal plane and transverse plane hip motion. \[25\] A systematic

review that investigated hip strength in patients with PFP

found strong evidence that hip abduction, external rotation,

and extension strength were decreased compared with unin­
jured control subjects. \[26\] Conflicting data exist on the specific

movement patterns that may be present in patients with

active PFP; however, the inability to ­eccentrically control hip

adduction and internal rotation may lead to greater dynamic

lower extremity valgus commonly seen during landing, squat­
ting, and running. \[27,28\]

Altered neuromuscular control strategies during land­

ing may be a potential factor related to lower extremity and
ACL injuries in women athletes. \[29,30\] In a study of 315 young
athletes, males had greater hip flexion at initial contact and
greater hip extensor moment compared with females. \[31\] There
was also significant preference to underutilize the hip com­

pared with the knee extensors in females, which indicates a
sex-specific hip strategy during drop vertical jumps. Decker
et al \[32\] showed a decrease in negative joint work (decreased

eccentric muscle contraction to absorb landing forces) at the

hip in females compared with males during landing. ­Similarly,

ACL reconstructed patients had greater hip moments ­during

the stance phase of gait that may provide increased protection
for the ACL. \[33\] Patients with patellar tendinopathy also dis­

played increased hip joint moments during hopping compared
with controls. \[34\] Proximal mechanisms may play a significant

role in neuromuscular control strategies for controlling and

compensating for knee loading during a myriad of complex

movements. Neuromuscular training positively alters hip
kinematics and kinetics. \[35\] Lephart et al \[35\] found increased
hip flexion at initial contact and increased peak internal hip

extensor moment following a plyometric training protocol.
These authors suggested that the modifications at the hip
likely increase the hamstring forces that protect the ACL. \[35\]

Hip posture may play an important role in the mechanical
efficiency of hamstrings in relation to quadriceps. \[36\]

Clearly, the hip plays a central role in dynamic lower extrem­

ity valgus. The purpose of the clinically related narrative,

Open Access Journal of Sports Medicine 2015:6

**292**

**submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**Dovepress**

aimed at sports medicine clinicians, was to identify and

discuss hip-focused exercise interventions that aim to address
dynamic lower extremity valgus. Specifically, hip muscle

activation, strength, and biomechanical outcomes are pre­

sented. Furthermore, we discuss practical applications that

may be utilized both clinically and in future randomized

controlled trials.

## Functional anatomy

Since strength, activation, and control of the hip play a critical

role in dynamic valgus, understanding the functional anatomy

of the hip is foundational in developing any successful inter­

vention program. The gluteus medius is the primary abductor
of the hip \[37–39\] and receives assistance in abduction from the

gluteus minimus and the piriformis. The proximal attachment

of gluteus medius is along the outer edge of the iliac crest

and is fan-shaped, spanning the iliac crest from the anterior

superior iliac spine to the posterior superior iliac spine. The

muscle tapers into a strong tendon and attaches distally on
the posterosuperior portion of the greater trochanter. \[40\] The
gluteus medius is specifically defined by three parts, anterior,

middle, and posterior, that are approximately equal in volume.
The anterior and middle fibers run almost vertical while the
posterior fibers run horizontal and almost parallel to the neck
of the femur. \[41\] Using fine wire electromyography (EMG),

the three segments of the gluteus medius have been found

to function in a phasic pattern during submaximal functional

activities such as walking, but were found to activate (both

onset and duration) more simultaneously during maximal

levels of activity such as the support phases of descending

stairs. \[42,43\]

The gluteus maximus is the largest muscle in the gluteal
region and one of the largest muscles in the body. \[37\] The

proximal attachments of the gluteus maximus are along

the posterior gluteal line of the ilium, dorsal surface of the

sacrum and coccyx, and the sacrotuberous ligament. It slopes

inferolaterally at a 45° angle across the ischial tuberosity and
attaches distally into the superficial fibers of the iliotibial
tract and the gluteal tuberosity of the femur. \[37,44\] While the

gluteus medius is the primary abductor of the hip, the gluteus

maximus functions primarily as an extensor but also as an

external rotator of the hip, allowing the gluteus maximus to
control motions in the sagittal and transverse planes. \[37\]

Proper functioning of the posterolateral hip musculature

during single limb weight bearing is essential to providing
proximal stability for lower extremity motion. Specifically,

the roles of these muscles are to stabilize the pelvis in the

frontal and transverse planes to maintain a level pelvis and

Hip-focused neuromuscular exercise for dynamic lower extremity valgus

control rotation at the hip. \[37–39,41,43,45,46\] In the frontal plane,

the hip abductors must produce a large abduction torque to

counteract the adduction torque produced from the product

of body weight and its larger external moment arm act­
ing at the hip. \[47\] Failure to produce the abduction force is

observed as a Trendelenburg posture, with the contralateral
pelvis dropping. \[47\] The important role of the hip abductors

in stabilizing the pelvis during single limb function is fur­

ther illustrated during the midstance phase of gait where

activation and force production of the abductors have been
observed to be the greatest. \[48,49\] In the transverse plane, the

abductors and external rotators work together to control hip
and pelvis motion. \[45,46\] Hence, weakness or inefficiency of the

posterolateral hip musculature would decrease stability of

the hip when loaded in a single limb weight-bearing stance,

resulting in an inability to maintain a neutral alignment of the

hip and knee. Therefore, much attention has been directed at

correcting or improving hip strength or activation and its role

in controlling dynamic lower extremity valgus.

## **Muscular activation with** **hip-focused exercises**

Hip muscle activation, particularly of the gluteus medius

and gluteus maximus, have been examined across a variety

of exercises commonly used during interventions. EMG

is commonly used to quantify the motor-unit activity in

a muscle or muscle group during intervention exercises

and is reported as the percentage of a maximal voluntary

isometric contraction (% MVIC). A greater level of muscle

activity has been assumed to lead to muscle strengthening

effects. It has been suggested that muscle activation during

an exercise should reach a minimum of 40%–60% MVIC in

order to achieve strength gains. \[50\] This has led to a myriad of

studies that have compared muscle activity during exercises.

This section summarizes the observed gluteus maximus and

gluteus medius muscle activation during non-weight-bearing,

controlled weight-bearing, and functional exercises. The
effects of common modifications to these exercises on hip

muscle activation are also discussed.

## Non-weight-bearing exercises

Non-weight-bearing hip exercises are often initiated to
target a specific muscle group in isolation, or during the

beginning stages of rehabilitation. Common exercises that

have been suggested to target the gluteus medius include

side-lying hip abduction, clam-shell exercises, and bridg­

ing exercises. Side-lying hip abduction (Figure 2A) is one

of the most consistently reported exercises in the literature.

Open Access Journal of Sports Medicine 2015:6 **submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**293**

Ford et al

**Dovepress**

**Figure 2** Common non-weight-bearing exercises.
**Notes:** ( **A** ) Side-lying hip abduction. ( **B** ) Side-lying clam with resistance. ( **C** ) Unilateral supine bridge. ( **D** ) Side-bridge (plank).

Activation of the gluteus medius during this exercise
have been reported to range from 23% to 81% MVIC. \[51–55\]

The side-lying hip abduction exercise was observed to have
16%–43% greater gluteus medius activation in studies \[51,53\]

when compared with the clam-shell exercise, where the hip

is abducted while keeping the feet together, with the hip and
knees flexed (Figure 2B). This is supported biomechanically

as the external hip adduction moment would be greater with
the hip and knee extended compared with a flexed position.

When comparing gluteus medius activation between side
lying hip abduction exercise and a unilateral supine bridge
exercise (Figure 2C), the reports are somewhat conflicting.
Two studies \[53,54\] observed 8%–13% less gluteus medius acti­

vation during the unilateral supine bridge exercise, whereas
one study \[55\] observed an 8% greater gluteus medius activation

during the side-lying hip abduction. The reasons for these
conflicting findings are unknown.

While the side-lying hip abduction exercise appears

to effectively activate the gluteus medius, the side-bridge

(plank) exercise has been shown to require greater activa­

tion of this muscle. The side-bridge exercise (Figure 2D) is

performed in a side-lying position with the trunk supported

by the upper extremity. The exercise is performed by lifting

the hip off the ground while maintain a neutral alignment

of the trunk, hips, and knees. The side-bridge has been

observed to require 35%–40% greater activation than the
side-lying hip abduction exercise. \[53,55\] The greater activation

during the side-bridge is likely due to the increased demand of

the gluteus medius to abduct the hip by lifting the body’s mass

and the need to stabilize the pelvis in the sagittal plane.

Common non-weight-bearing exercises to target the

gluteus maximus are supine bridging exercises where hip

extension is performed by lifting the body’s mass. Gluteus

maximus activation have been observed to range between

17% and 25% MVIC during a bilateral supine exercise and

between 35% and 54% MVIC during a unilateral supine
bridging exercise. \[53–55\] The magnitudes of gluteus maxi­

mus activation during these bridging exercises are similar

compared with the simplest non-weight-bearing exercise

with individuals extending the hip against gravity. This

is commonly done in a quadruped position and extend­
ing the hip while the knee is flexed. Direct comparison

between the quadruped hip extension and unilateral bridging

exercises reveals an approximately 5% difference in glu­
teus maximus activation. \[53,54\] However, the observed gluteus

maximus activation during these exercises may be misleading

and not result in strength gains, because there is evidence

to suggest that simply contracting the gluteal muscles in a

standing position activates the gluteus maximus 20% more

than performing a unilateral bridging exercise.

## Controlled weight-bearing exercises

As previously mentioned, the hip abductors must produce

a large abduction torque to counteract the adduction torque

produced from the product of the body weight and its larger

external moment arm acting at the hip to stabilize the pelvis
during single limb activities. \[48,49\] Controlled weight-bearing

exercises commonly used to target the gluteus medius include

hip hikes (pelvic drops), single limb squats (Figure 3A), and

lateral step-ups (Figure 3B). Activation of the gluteus medius

during these exercises has been reported to range between

38% and 58% MVIC for hip hikes, 38% and 60% MVIC

for lateral step-ups, and 48% and 82% MVIC for single
limb squats. \[51–57\] Only one study was found that examined

Open Access Journal of Sports Medicine 2015:6

**294**

**submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**Dovepress**

Hip-focused neuromuscular exercise for dynamic lower extremity valgus

**Figure 3** Common controlled weight-bearing exercises.
**Notes:** ( **A** ) Single leg squat. ( **B** ) Lateral box step-ups. ( **C** ) Forward box step-down. ( **D** ) Single leg dead lift.

differences across all three exercises, and it reported a 22%

and 24% greater activation of the gluteus medius during a

single limb squat exercise compared with a lateral step-up and
hip hike exercise, respectively. \[53\] Collectively, these findings

suggest that there is a negligible difference between the hip

hike and lateral step-up exercises. However, it appears that

there is a meaningful increase in the demand of the gluteus

medius during a single limb squat.

Single limb squat, step-up (lateral and forward, Figure 3C),

and single limb dead lift (Figure 3D) exercises are controlled

weight-bearing exercises that are commonly used to target the

gluteus maximus. Activation of the gluteus maximus during

these exercises has been reported to range between 41% and

71% MVIC for single limb squats, 29% and 64% MVIC for

lateral step-ups, 23% and 74% MVIC for forward step-ups,
and 59% MVIC for single limb dead lifts. \[51,53–57\] Differences in

gluteus maximus activation between the forward and lateral
step-up exercises are conflicting, with one study \[56\] report­
ing an 18% increase and another study \[53\] reporting a 9%

decrease in gluteus maximus activation during the forward
versus the lateral step-up exercise. There is also conflicting

evidence when comparing single limb squat and the single
limb dead lift exercises, with one study \[51\] reporting no dif­
ference and another study \[53\] reporting a 12% greater gluteus

maximus activation during the squat exercise. There is con­

sistent evidence suggesting that there is a 7%–16% increase

in gluteus maximus during the single limb squat compared
with the forward step-up exercise. \[53,57\] Only one study \[53\] was

found that examined gluteus maximus activation across all

four exercises, and it reported a high level of activation dur­

ing all controlled weight-bearing exercises, with the greatest

activation observed during the single limb squat.

Open Access Journal of Sports Medicine 2015:6

## Functional exercises

Increasing the complexity of exercises that continue to target

the gluteal muscles in a more dynamic and functional move­

ment pattern is a necessary component for an intervention

program. Functional exercises commonly used to target

the gluteus medius and gluteus maximus include lateral

band walks (Figure 4A), side lunges (Figure 4B), forward

lunges (Figure 4C), and rear lunges (Figure 4D). There are

limited studies that have examined activation of the gluteal

muscles during these exercises. Gluteus medius activation

during these exercises have been reported to be 30%–61%

MVIC for lateral band walks, 39% MVIC for side lunges,

and 19%–42% MVIC for forward lunges. Gluteus maximus

activation during these exercises have been reported to be

27%–28% MVIC for lateral band walks, 41% MVIC for

side lunges, and 20%–44% MVIC for forward lunges. \[51,54,55\]
Only one study \[51\] was found that compared the gluteal muscle

activation across all three exercises. A comparison of gluteus

medius activation between the functional exercises reported a

22%–25% greater activation of the gluteus medius during the

lateral band walk compared with the lunge exercises while

there was negligible difference between the lunge ­exercises.

A comparison of gluteus maximus activation showed a

negligible difference between the forward and side lunge

exercises, but there was 14%–17% greater gluteus maximus

activation compared with the lateral band walks. These
findings are not unexpected, as the lunge exercises require
greater hip dynamic flexion that would increase the demand

on the gluteus maximus.

Plyometric (ballistic) exercises are often used in injury

prevention settings or during the latter stages of rehabilitation.

Plyometric exercise has been previously operationally

**submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**295**

Ford et al

**Dovepress**

**Figure 4** Common functional exercises.
**Notes:** ( **A** ) Lateral resisted band walks. ( **B** ) Side lunges. ( **C** ) Forward lunges. ( **D** ) Rear cross-over lunges. Note that during the rear cross-over lunge it is extremely
challenging to control the pelvis, which results in apparent lower extremity valgus. Care should be taken to progress the exercises and limit step distances as appropriate.

defined as an “… activity that involves and capitalizes on

the mechanisms of the stretch-shortening cycle to increase
the efficiency of force production at a joint or increase
performance”. \[58\] A number of papers provide detailed exer­
cise descriptions and progressions. \[58–61\] These exercises are

important to assess readiness for return to play, but may also
provide therapeutic benefit by preferentially recruiting the

gluteus medius and maximus musculature. Gluteus medius

muscle activity is highest during single-limb sagittal plane

hurdle hops (100% MVIC), double-limb sagittal plane hurdle

hops (61% MVIC), and split squat jumps (62% MVIC), with

lesser activation during non-sagittal plane double-limb land­

ings in the frontal (40% MVIC) and transverse (47% MVIC)
planes. \[62\] Similarly, the gluteus maximus is most highly

activated during double-limb (63% MVIC) and single-limb

(69.4% MVIC) sagittal plane landings, and less active in other
planes (\<40% MVIC). \[62\] Of note, these results are during a

land, and do not incorporate a subsequent jump which is

common during plyometric activities. True plyometric activi­
ties, including a rapid change of direction, elicit significantly

higher muscle activation (150%–190% MVIC) than isolated
landings or controlled exercises. \[63\] Continued work is needed

to explore gluteal activation patterns during other commonly

used functional exercises.

## Influence of exercise modification on gluteal activation

During non-weight-bearing exercises, limb position, and
joint angle can directly influence the activation of the gluteal
muscles. Specifically, there is evidence to suggest that rota­

tion at the hip during the side-lying hip abduction exercise

can directly influence the magnitude of gluteus medius
activation. \[64\] It was reported that activation of the gluteus

medius during the side-lying hip abduction exercise was

16% greater with the hip internally rotated than with the hip

in neutral. In addition, gluteus maximus activation can be
directly influenced by the position of the hip in the sagittal
plane during non-weight-bearing hip extension exercises. \[65\]

There is evidence to suggest that activation of the gluteus
maximus is 12%–14% greater at 30–60 degrees of hip flexion
compared with 90 degrees of hip flexion. Collectively, these

data suggest that activation of the gluteal muscles is depen­

dent on the length-tension curve where the gluteal muscles

may have the greatest activation when they are close to their

ideal length. These conclusions are based on hip muscle

activation during isometric contractions. Additional work

is needed to examine these relationships during isotonic

exercises typically used in intervention programs.

The position of the trunk during controlled weight
bearing and functional exercises has been suggested to
influence the demands on the hip muscles. Powers \[66\] discusses

this relationship where trunk position, either in the sagittal

or frontal plane, that moves the body center of mass (and

resultant ground reaction force vector) away from the hip

joint will increase the demand placed on the hip muscles.

This theory has been supported by empirical evidence that

reports greater hip muscle activation during jumping and
running tasks with the trunk in a more flexed position. \[67,68\]

There are limited studies that have examined the role of the

trunk during weight-bearing and/or functional exercises com­

monly used in intervention programs. Only one study could
be found that examined the influence of sagittal plane trunk

**296**

**submit your manuscript** | \<www.dovepress.com> Open Access Journal of Sports Medicine 2015:6

**Dovepress**

**Dovepress**

position on gluteus maximus activation during a forward
lunge. \[69\] The authors reported that there was a 6% increase in

gluteus maximus activation during a forward lunge with the

trunk forward compared with the trunk in an erect position.
Further research is needed to clarify the effects of modifica­

tions of exercises on hip muscle activation.

## **Precautions in interpreting gluteal** **muscle activation research**

As previously mentioned, it has been suggested that muscle

activation during an exercise should reach a minimum of
40%–60% MVIC in order to achieve strength gains. \[50\] These

values were derived through procedures that normalized the

EMG signals during exercise to the peak root mean square
amplitude during MVICs at specific joint angles. The _Journal_

_of Electromyography and Kinesiology_ standards for report­

ing EMG data advised authors to report such information as

the joint angle and/or muscle length during the MVIC, and

the rate of rise of force. This implies that these factors will

Hip-focused neuromuscular exercise for dynamic lower extremity valgus

influence the EMG signal during MVICs and, consequently,

the normalized values observed during exercises.

The values summarized in the preceding sections were

reported as normalized values using various methods when

assessing MVICs. Therefore, it should not be concluded that

exercises reported to exceed 40%–60% MVIC will achieve

strength gains. Clinicians should examine the comparisons

between exercises, within studies, to determine exercises that

have been shown to induce greater muscle activation when

initiating exercises during clinical practice.

## **Biomechanical and strength** **outcomes with hip-focused** **interventions**

A number of recent studies have examined the effects of hip
focused intervention programs on multi-planar hip strength

and lower extremity biomechanical measures of dynamic
lower extremity valgus (Table 1). \[70–80\] These programs have

been wide-ranging in their implementation, based largely on

**Table 1** Components, strength, and biomechanical outcomes of hip-focused intervention programs

**Program components** **Outcome measures**

NWB WB-S WB-F/T BAL TS Hip strength

ABD ER EXT

Biomechanics

Baldon et al \[74\] x x x x ↑ 15%\* Ecc 0% Ecc NT - ↓ ipsilateral trunk inclination, pelvis

contralateral depression, hip

adduction and knee abduction during

a single leg squat
Dolak et al \[78\] x x x ↑ 21%*Iso ↑ 29% Iso NT - NT
Earl and Hoch \[70\] x x x ↑ 12%* Iso ↑ 17%\* Iso NT - ↓ peak internal knee abduction

moment during stance phase of

running
Ismail et al \[72\] x x ↑ 41%*Con ↑ 33%* Con NT - NT
↑ 15%*Ecc ↑ 29%* Ecc

↑ 33%*Con
↑ 29%* Ecc

NT - NT

Khayambashi et al \[75\] x ↑ 32%–42%*Iso ↑ 37%–56%* Iso NT - NT
McCurdy et al \[76\] x NT NT NT -  No change in knee abduction angle

during a bilateral drop-jump task
Myer \[77\] x x x x ↑ 15%–17%*Con NT NT - NT
Nakagawa et al \[79\] x x x x ↑ 15% Ecc ↑ 6% Ecc NT - NT
Stearns and x x x ↑ 7%* Iso NT ↑ 8%\* Iso - ↑ peak hip and knee flexion, ↓
Powers \[71\]

x x x ↑ 7%*Iso NT ↑ 8%* Iso - ↑ peak hip and knee flexion, ↓ average

internal knee adduction moment,
↓ internal knee/hip extension moment

ratio during a bilateral drop-jump task

Willy and Davis \[80\] x x x ↑ 42%*Iso ↑ 24.1%* Iso NT -  No significant kinematic changes

during running

```
                                                     - ↓ hip adduction, hip internal rotation,
```

and contralateral pelvic drop during

single limb squat

**Note:** \*Reported as statistically significant changes in strength.
**Abbreviations:** ABD, abduction; ER, external rotation; EXT, extension; Ecc, eccentric; Con, concentric; NWB, non-weight-bearing; WB-S, weight-bearing sagittal plane;
WB-F/T, weight-bearing frontal/transverse plane; BAL, ballistic; TS, trunk stabilization; NT, not tested; Iso, isometric.

Open Access Journal of Sports Medicine 2015:6 **submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**297**

Ford et al

the population targeted or stage in the rehabilitation process.

Hip-focused interventions have been used in healthy athletes
for knee injury prevention strategies, \[77\] and in those diagnosed
with PFP. \[70,72,74,75\] The duration and volume of hip-focused

programs have also varied considerably, with all programs

occurring two to three times per week, but ranging from 4

to 12 weeks in duration. \[70–76\]

Because of the heterogeneity in populations and stages

of rehabilitation, the exercises used to target the hip have

also been variable. Some programs have focused strictly
on isolated non-weight-bearing hip exercises, \[72,75\] while

others have used a combination of non-weight-bearing and

weight-bearing/functional exercises focused either in one
(sagittal) or multiple (frontal and transverse) planes. \[74,76,78,79\]

Although all programs were varied, common exercises were

used between research groups. Side-lying hip abduction,

prone hip extension, clam-shells (resisted), and seated hip

external rotation were common non-weight-bearing exercises

used in hip focused interventions. Weight-bearing exercises,

including single limb squats and deadlifts, lunges, forward

and lateral step-ups, and resisted hip external rotation are

also prevalent amongst hip-focused programs. Additionally,

some programs have included trunk strengthening as part of

their hip-focused intervention, using standard exercises such

as planks or incorporating an unstable support surface (eg,

BOSU balance trainer) to encourage trunk activation and
stabilization, \[71,74,77\] while other programs have focused on the

latter stages of rehabilitation by including plyometric activi­
ties in addition to standard strengthening techniques. \[71,77\]

Although the implementation methods of hip-focused

intervention programs have been variable, these programs

consistently produce improved measures of hip extension,

abduction, and external rotation strength (Table 1). Strength
gains of 7%–42% in hip abduction, \[22,70–72,75,77–80\] 6%–56% in
hip external rotation, \[70,72,75,78–80\] and 8% in hip extension \[71\] have

been previously reported. However, these strength gains need

to be interpreted cautiously. Although no previous studies
have reported a significant reduction in hip strength, not all
studies have reported statistically significant improvements
in strength after hip-focused interventions \[74,80\] which may be

due to differences in the components, duration, and inten­

sity of the programs, or the variability in the methodology

of strength assessment, such as instrumentation (isokinetic

versus handheld dynamometer), type of contraction (eccen­

tric versus concentric versus isometric), and patient position

(open versus closed chain). The largest gains in strength have

typically been found in isometric strength, although we con­

tend that eccentric strength may be of the most importance in

**Dovepress**

controlling dynamic lower extremity valgus during jumping

or cutting. Past research on the role of hip-focused interven­

tions resulting in improved eccentric hip strength has been
limited, \[72,74,79\] and no studies have examined eccentric strength

of the gluteus maximus or the combination of the three car­

dinal planes of hip motion.

More importantly, strength gains resulting from hip
focused interventions have translated to improved bio­

mechanics at the hip and knee during athletic activities
(Table 1). Previous studies report greater peak hip flexion
during a jump landing \[71\] and less hip adduction and internal

rotation, ipsilateral trunk inclination, and contralateral pelvis
depression during a single leg squat, \[74\] despite only modest

gains in hip strength. At the knee, hip-focused interventions

may result in lower levels of knee adduction moments dur­
ing running, \[70\] and lower knee-hip extensor moment ratios

and peak knee abduction angles and moments during jump
landings, \[71\] although other studies have found no specific bio­
mechanical changes at the knee. \[76\] Examining previous pro­

grams that have documented biomechanical outcomes after

training, hip-focused interventions that include closed chain

activities and trunk stabilization appear to make the largest
positive impact on distal biomechanics. \[70,71,74\] Considering

the demands on the gluteus maximus during closed chain

and ballistic exercises in the frontal and transverse planes

and the limited research on the biomechanical effects of

these exercises, further research to optimize the effects of

hip-focused intervention is warranted.

## **Practical application and conclusion**

Attention should be devoted to developing evidence to

support progression of exercises with varying bases of sup­

port (Figure 5A), sports-related tasks with external load

(Figure 5B), and resisted bands (Figure 5C and D). For

instance, the resisted vertical bridge (Figure 5D) is a potential

progression from the supine bilateral bridge with the ability

to add changes in resistance in a vertical posture. The upright

position transitions from the bridge to a closed kinetic chain

posture as the femur loads into the acetabulum, which could

be considered a more functional position in relation to human

movement. The vertical bridge also allows the opportunity

to engage the free upper extremities into other more “func­

tional activities” that can promote perturbations to the trunk,

ultimately engaging more core musculature than the isolated

nature of the supine bridge.

There may be a tendency to assume a linear ­relationship

between improved strength, improved biomechanical

variables in a sports-related task like jumping or landing,

**298**

**submit your manuscript** | \<www.dovepress.com> Open Access Journal of Sports Medicine 2015:6

**Dovepress**

**Dovepress**

Hip-focused neuromuscular exercise for dynamic lower extremity valgus

**Figure 5** Late stage hip-focused exercises.
**Notes:** ( **A** ) BOSU single knee balance. ( **B** ) Weighted runner. ( **C** ) Resisted band single leg squats. ( **D** ) Resisted vertical bridge. Note that the resisted band in ( **C** ) should apply
a slight force that progresses the athlete to activate the hip musculature to prevent lower extremity valgus. Care should be taken to progress the exercises and magnitude

of resistance.

and improved biomechanical variables in the performance of

the actual sport or activity. As this review has demonstrated,

hip-focused exercises generally increase EMG activity,

and increased EMG activity generally results in improved

strength, which further results in improved task-related

­biomechanics. However, improved strength does not always
result in changes to important biomechanical variables, \[81\]

and improved biomechanics in sports-related tasks does

not necessarily equal improved biomechanical variables in
performance of the sport itself. \[80\] Controlling dynamic lower

extremity valgus is complex (Figure 1) and likely involves

a combination of strengthening and activation exercises

and motor control of the hip, as well as use of feedback to
facilitate integration into higher level activities. \[82–87\] Even

with the addition of feedback, hip-targeted strengthening

alone is not the answer. Dynamic lower extremity valgus
and hip muscle inhibition is likely influenced by pain or
inflammation, \[88\] body structure, \[89,90\] fatigue, \[91–94\] pubertal age
and maturation, \[9,31,95\] fear and other psychosocial variables, \[96–98\]
and prior injury. \[99,100\] With the evidence and these variables

in mind, a focus on strengthening the hip to control dynamic

valgus is a great start for many reasons, including that it

helps clinicians move away from a local focus to a more

regional focus for pathologies at the knee. The next step

in the evolution of treating patients with knee pathology is
a global focus considering fixed factors like sex and body

structure, re-education strategies like modes of feedback,
physiological factors like pain, inflammation, and fatigue,

and psychosocial factors like fear and anxiety (Figure 6).

Figure 6 was constructed by the authors, based on the results

of this evidenced-based review, to present a theoretical

framework of the main steps to consider when initiating

hip-focused neuromuscular exercises to modify dynamic

lower extremity valgus, in addition to highlighting a few

of the multivariate factors that should be considered when

implementing hip-focused neuromuscular exercises in

order to control dynamic lower extremity valgus. These

factors likely play a critical role in the relative success of

a program at each step along the continuum from initiating

improved hip strength and activation to integrated neuro­
muscular control during a variety of movements to the final

optimization of safe biomechanics during high-level activi
ties and sports.

This clinical narrative is limited to the current strength

of literature that was discussed. The strength and quality

of literature is varied, with few randomized controlled

trials. Therefore, caution should be used when interpret­

ing results from lower quality and less controlled studies.

Additionally, it was out of the scope of the current review to

exhaustively cover and address special patient populations

and adaptations that should be considered with some of the

exercises presented. In summary, the research indicates that

hip-focused neuromuscular exercise may be an important

component to consider when treating patients with ACL

and PFP knee pathologies. Importantly, it also appears that

targeting hip musculature activation and strength may aid in

modifying dynamic lower extremity valgus, which may help

to reduce the risk of future ACL injury and PFP. Research

should continue to develop to identify and understand the

mechanistic relationship between optimized biomechanics

Open Access Journal of Sports Medicine 2015:6 **submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**299**

Ford et al

**Dovepress**

Motor learning

Pain

Fear

Inflammation

**Figure 6** Theoretical framework for hip-focused neuromuscular exercises to modify dynamic lower extremity valgus.
**Notes:** Theoretical framework of the main steps to consider when initiating hip-focused neuromuscular exercises to modify dynamic lower extremity valgus. The spokes
represent a non-exhaustive list of common factors that likely influence the relative success of a program.

during sports and hip-focused neuromuscular exercise

interventions.

## **Disclosure**

The authors report no conflicts of interest in this work.

## **References**

1. Powers CM. The influence of abnormal hip mechanics on knee injury:

a biomechanical perspective. _J Orthop Sports Phys Ther_ . 2010;40(2):

42–51.

2. Hewett TE, Myer GD, Ford KR, et al. Biomechanical measures of

neuromuscular control and valgus loading of the knee predict anterior
cruciate ligament injury risk in female athletes: a prospective study. _Am_
_J Sports Med_ . 2005;33(4):492–501.
3\. Hewett TE, Myer GD, Ford KR. Anterior cruciate ligament injuries in

female athletes: Part 1, mechanisms and risk factors. _Am J Sports Med_ .
2006;34(2):299–311.
4\. Paterno MV, Schmitt LC, Ford KR, et al. Biomechanical measures during

landing and postural stability predict second anterior cruciate ligament
injury after anterior cruciate ligament reconstruction and return to sport.
_Am J Sports Med_ . 2010;38(10):1968–1978.
5\. Myer GD, Ford KR, Di Stasi SL, Barber Foss KD, Micheli LJ, Hewett TE.

High knee abduction moments are common risk factors for patellofemo­
ral pain (PFP) and anterior cruciate ligament (ACL) injury in girls: is
PFP itself a predictor for subsequent ACL injury? _Br J Sports Med_ .
2015;49(2):118–122.
6\. Ford KR, Myer GD, Hewett TE. Valgus knee motion during landing in

high school female and male basketball players. _Med Sci Sports Exerc_ .
2003;35(10):1745–1750.
7\. Ford KR, Myer GD, Toms HE, Hewett TE. Gender differences in the

kinematics of unanticipated cutting in young athletes. _Med Sci Sports_
_Exerc_ . 2005;37(1):124–129.
8\. Ford KR, Myer GD, Smith RL, Vianello RM, Seiwert SL, Hewett TE.

A comparison of dynamic coronal plane excursion between matched
male and female athletes when performing single leg landings. _Clin_
_Biomech_ . 2006;21(1):33–40.

9. Ford KR, Shapiro R, Myer GD, van den Bogert AJ, Hewett TE.

Longitudinal sex differences during landing in knee abduction in young
athletes. _Med Sci Sports Exerc_ . 2010;42(10):1923–1931.
10\. Malinzak RA, Colby SM, Kirkendall DT, Yu B, Garrett WE. A compari­

son of knee joint motion patterns between men and women in selected
athletic tasks. _Clin Biomech_ . 2001;16(5):438–445.
11\. Hewett TE, Myer GD, Ford KR. Decrease in neuromuscular control

about the knee with maturation in female athletes. _J Bone Joint Surg_
_Am_ . 2004;86-A(8):1601–1608.
12\. Chappell JD, Yu B, Kirkendall DT, Garrett WE. A comparison of knee

kinetics between male and female recreational athletes in stop-jump
tasks. _Am J Sports Med_ . 2002;30(2):261–267.
13\. McLean SG, Huang X, Su A, van den Bogert AJ. Sagittal plane biome­

chanics cannot injure the ACL during sidestep cutting. _Clin Biomech_ .
2004;19:828–838.
14\. Kernozek TW, Torry MR, Van Hoof H, Cowley H, Tanner S. Gender

differences in frontal and sagittal plane biomechanics during drop
landings. _Med Sci Sports Exerc_ . 2005;37(6):1003–1012.
15\. Zeller BL, McCrory JL, Kibler WB, Uhl TL. Differences in kinematics

and electromyographic activity between men and women during the
single-legged squat. _Am J Sports Med_ . 2003;31(3):449–456.
16\. Pappas E, Hagins M, Sheikhzadeh A, Nordin M, Rose D. Biomechanical

differences between unilateral and bilateral landings from a jump:
gender differences. _Clin J Sport Med_ . 2007;17(4):263–268.
17\. Hewett TE, Ford KR, Myer GD, Wanstrath K, Scheper M. Gender dif­

ferences in hip adduction motion and torque during a single leg agility
maneuver. _J Orthop Res_ . 2006;24(3):416–421.
18\. Hewett TE, Stroupe AL, Nance TA, Noyes FR. Plyometric training

in female athletes. Decreased impact forces and increased hamstring
torques. _Am J Sports Med_ . 1996;24(6):765–773.
19\. Carson DW, Ford KR. Sex differences in knee abduction during landing:

a systematic review. _Sports Health_ . 2011;3(4):373–382.
20\. Olsen OE, Myklebust G, Engebretsen L, Bahr R. Injury mechanisms

for anterior cruciate ligament injuries in team handball: a systematic
video analysis. _Am J Sports Med_ . 2004;32(4):1002–1012.
21\. Krosshaug T, Nakamae A, Boden BP, et al. Mechanisms of anterior

cruciate ligament injury in basketball: video analysis of 39 cases. _Am_
_J Sports Med_ . 2007;35(3):359–367.

**300**

**submit your manuscript** | \<www.dovepress.com> Open Access Journal of Sports Medicine 2015:6

**Dovepress**

**Dovepress**

22. Boden BP, Dean GS, Feagin JA, Garrett WE. Mechanisms of anterior

cruciate ligament injury. _Orthopedics_ . 2000;23(6):573–578.
23\. Brent J, Myer GD, Ford KR, Paterno M, Hewett T. The effect of sex

and age on isokinetic hip abduction torques. _J Sport Rehabil_ . 2013;
22(1):41–46.
24\. Ford KR, Taylor-Haas JA, Genthe K, Hugentobler J. Relationship

between hip strength and trunk motion in college cross-country runners.
_Med Sci Sports Exerc_ . 2013;45(6):1125–1130.
25\. Taylor-Haas JA, Hugentobler JA, DiCesare CA, et al. Reduced hip

strength is associated with increased hip motion during running in
young adult and adolescent male long-distance runners. _Int J Sports_
_Phys Ther_ . 2014;9(4):456–467.
26\. Prins MR, van der Wurff P. Females with patellofemoral pain syn­

drome have weak hip muscles: a systematic review. _Aust J Physiother_ .
2009;55(1):9–15.
27\. Souza RB, Powers CM. Differences in hip kinematics, muscle strength,

and muscle activation between subjects with and without patellofemoral
pain. _J Orthop Sports Phys Ther_ . 2009;39(1):12–19.
28\. Willson JD, Davis IS. Lower extremity mechanics of females with and

without patellofemoral pain across activities with progressively greater
task demands. _Clin Biomech_ . 2008;23(2):203–211.
29\. Ireland ML. The female ACL: why is it more prone to injury? _Orthop_

_Clin North Am_ . 2002;33(4):637–651.
30\. Knapik JJ, Bauman CL, Jones BH, Harris JM, Vaughan L. Preseason

strength and flexibility imbalances associated with athletic injuries in
female collegiate athletes. _Am J Sports Med_ . 1991;19(1):76–81.
31\. Ford KR, Myer GD, Hewett TE. Longitudinal effects of maturation on

lower extremity joint stiffness in adolescent athletes. _Am J Sports Med_ .
2010;38(9):1829–1837.
32\. Decker MJ, Torry MR, Wyland DJ, Sterett WI, Richard Steadman J.

Gender differences in lower extremity kinematics, kinetics and energy
absorption during landing. _Clin Biomech_ . 2003;18(7):662–669.
33\. DeVita P, Hortobagyi T, Barrier J. Gait biomechanics are not normal after

anterior cruciate ligament reconstruction and accelerated rehabilitation.
_Med Sci Sports Exerc_ . 1998;30(10):1481–1488.
34\. Souza RB, Arya S, Pollard CD, Salem G, Kulig K. Patellar tendinopa­

thy alters the distribution of lower extremity net joint moments during
hopping. _J Appl Biomech_ . 2010;26(3):249–255.
35\. Lephart SM, Abt JP, Ferris CM, et al. Neuromuscular and biome­

chanical characteristic changes in high school athletes: a plyometric
versus basic resistance program. _Br J Sports Med_ . 2005;39(12):

932–938.

36. Shultz SJ, Beynnon BD, Schmitz RJ. Sex differences in coupled knee

motions during the transition from non-weight-bearing to weightbearing. _J Orthop Res_ . 2009;27(6):717–723.
37\. Moore KL. _Clinically Oriented Anatomy_ . Baltimore, MD, USA:

­Williams and Wilkins; 1992.
38\. Kumagai M, Naoto S, Higuchi F. Functional evaluation of hip abductor

muscles with use of magnetic resonance imaging. _J Orthop Res_ . 1997;15:

888–893.

39. Inman VT. Functional aspects of the abuctor muscles of the hip. _J Bone_

_Joint Surg Am_ . 1947;29(3):607–619.
40\. Pfirrmann CW, Chung CB, Theumann NH, Trudell DJ, Resnick D.

Greater trochanter of the hip: attachment of the abductor mechanism and
a complex of three bursae – MR imaging and MR bursography in cadavers
and MR imaging in asymptomatic volunteers. _Radiology_ . 2001;221(2):

469–477.

41. Gottschalk F, Kourosh S, Leveau B. The functional anatomy of ten­

sor fasciae latae and gluteus medius and minimus. _J Anat_ . 1989;166:

179–189.

42. Soderberg GL, Dostal WF. Electromyographic study of three parts

of the gluteus medius muscle during functional activities. _Phys Ther_ .
1978;58(6):691–696.
43\. Lyons K, Perry J, Gronley JK, Barnes L, Antonelli D. Timing and

relative intensity of hip extensor and abductor muscle action during
level and stair ambulation. An EMG study. _Phys Ther_ . 1983;63(10):

1597–1605.

Hip-focused neuromuscular exercise for dynamic lower extremity valgus

44. Kendall FP, McCreary EK, Provance PG. _Muscles Testing and Function_ .

4th ed. Philadelphia, PA, USA: Lippincott Williams & Wilkins;

1993.

0001. Earl JE. Gluteus medius activity during 3 variations of isometric single
      leg stance. _J Sport Rehabil_ . 2004;13:1–11.

0001. Schmitz RJ, Riemann BL, Thompson T. Gluteus medius activity

during isometric closed-chain hip rotation. _J Sport Rehabil_ . 2002;11:

179–188.

47. Neumann DA. Biomechanical analysis of selected principles of hip

joint protection. _Arthritis Care Res_ . 1989;2(4):146–155.
48\. Neumann DA, Cook TM, Sholty RL, Sobush DC. An electromyograpic

analysis of hip abductor muscle activity when subjects are carrying
loads in one of both hands. _Phys Ther_ . 1992;72(3):207–217.
49\. Anderson FC, Pandy MG. Individual muscle contributions to support

in normal walking. _Gait Posture_ . 2003;17(2):159–169.
50\. Andersen LL, Magnusson SP, Nielsen M, Haleem J, Poulsen K, Aagaard P.

Neuromuscular activation in conventional therapeutic exercises and
heavy resistance exercises: implications for rehabilitation. _Phys Ther_ .
2006;86(5):683–697.
51\. DiStefano LJ, Blackburn JT, Marshall SW, Padua DA. Gluteal muscle

activation during common therapeutic exercises. _J Orthop Sports Phys_
_Ther_ . 2009;39(7):532–540.
52\. Bolgla LA, Uhl TL. Electromyographic analysis of hip rehabilitation

exercises in a group of healthy subjects. _J Orthop Sports Phys Ther_ .
2005;35(8):487–494.
53\. Boren K, Conrey C, Le Coguic J, Paprocki L, Voight M, Robinson TK.

Electromyographic analysis of gluteus medius and gluteus maximus
during rehabilitation exercises. _Int J Sports Phys Ther_ . 2011;6(3):

206–223.

54. Selkowitz DM, Beneck GJ, Powers CM. Which exercises target the

gluteal muscles while minimizing activation of the tensor fascia lata?
Electromyographic assessment using fine-wire electrodes. _J Orthop_
_Sports Phys Ther_ . 2013;43(2):54–64.
55\. Ekstrom RA, Donatelli RA, Carp KC. Electromyographic analysis of

core trunk, hip, and thigh muscles during 9 rehabilitation exercises.
_J Orthop Sports Phys Ther_ . 2007;37(12):754–762.
56\. Ayotte NW, Stetts DM, Keenan G, Greenway EH. Electromyographical

analysis of selected lower extremity muscles during 5 unilateral weightbearing exercises. _J Orthop Sports Phys Ther_ . 2007;37(2):48–55.
57\. Lubahn AJ, Kernozek TW, Tyson TL, Merkitch KW, Reutemann P,

Chestnut JM. Hip muscle activation and knee frontal plane motion
during weight-bearing therapeutic exercises. _Int J Sports Phys Ther_ .
2011;6(2):92–103.
58\. Chmielewski TL, Myer GD, Kauffman D, Tillman SM. Plyometric

exercise in the rehabilitation of athletes: physiological responses and
clinical application. _J Orthop Sports Phys Ther_ . 2006;36(5):308–319.
59\. Myer GD, Ford KR, Hewett TE. Rationale and clinical techniques for

anterior cruciate ligament injury prevention among female athletes.
_J Athl Train_ . 2004;39(4):352–364.
60\. Myer GD, Paterno MV, Ford KR, Hewett TE. Neuromuscular train­

ing techniques to target deficits before return to sport after anterior
cruciate ligament reconstruction. _J Strength Cond Res_ . 2008;
22(3):987–1014.
61\. Myer GD, Ford KR, Brent JL, Hewett TE. An integrated approach to

change the outcome Part II: Targeted neuromuscular training techniques
to reduce identified ACL injury risk factors. _J Strength Cond Res_ . 2012;
26(8):2272–2292.
62\. Struminger AH, Lewek MD, Goto S, Hibberd E, Blackburn JT.

­Comparison of gluteal and hamstring activation during five commonly
used plyometric exercises. _Clin Biomech_ . 2013;28(7):783–789.
63\. Hanson AM, Padua DA, Troy Blackburn J, Prentice WE, Hirth CJ.

Muscle activation during side-step cutting maneuvers in male and
female soccer athletes. _J Athl Train_ . 2008;43(2):133–143.
64\. Lee JH, Cynn HS, Kwon OY, et al. Different hip rotations influence

hip abductor muscles activity during isometric side-lying hip abduction
in subjects with gluteus medius weakness. _J Electromyogr Kinesiol_ .
2014;24(2):318–324.

Open Access Journal of Sports Medicine 2015:6 **submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**301**

Ford et al

65. Worrell TW, Karst G, Adamczyk D, et al. Influence of joint position

on electromyographic and torque generation during maximal voluntary
isometric contractions of the hamstrings and gluteus maximus muscles.
_J Orthop Sports Phys Ther_ . 2001;31(12):730–740.
66\. Powers CM. The influence of altered lower-extremity kinematics on

patellofemoral joint dysfunction: a theoretical perspective. _J Orthop_
_Sports Phys Ther_ . 2003;33(11):639–646.
67\. Kopper B, Ureczky D, Tihanyi J. Trunk position influences joint activation

pattern and physical performance during vertical jumping. _Acta Physiol_
_Hung_ . 2012;99(2):194–205.
68\. Teng HL, Powers CM. Influence of trunk posture on lower extremity ener­

getics during running. _Med Sci Sports Exerc_ . 2015;47(3):625–630.
69\. Farrokhi S, Pollard CD, Souza RB, Chen YJ, Reischl S, Powers CM.

Trunk position influences the kinematics, kinetics, and muscle activity
of the lead lower extremity during the forward lunge exercise. _J Orthop_
_Sports Phys Ther_ . 2008;38(7):403–409.
70\. Earl JE, Hoch AZ. A proximal strengthening program improves pain,

function, and biomechanics in women with patellofemoral pain syndrome.
_Am J Sports Med_ . 2011;39(1):154–163.
71\. Stearns KM, Powers CM. Improvements in hip muscle performance

result in increased use of the hip extensors and abductors during a
landing task. _Am J Sports Med_ . 2014;42(3):602–609.
72\. Ismail MM, Gamaleldein MH, Hassa KA. Closed kinetic chain exercises

with or without additional hip strengthening exercises in management
of patellofemoral pain syndrome: a randomized controlled trial. _Eur J_
_Phys Rehabil Med_ . 2013;49(5):687–698.
73\. Garrison JC, Bothwell J, Cohen K, Conway J. Effects of hip strengthening

on early outcomes following anterior cruciate ligament reconstruction.
_Int J Sports Phys Ther_ . 2014;9(2):157–167.
74\. Baldon Rde M, Serrao FV, Scattone Silva R, Piva SR. Effects of

functional stabilization training on pain, function, and lower extremity
biomechanics in women with patellofemoral pain: a randomized clinical
trial. _J Orthop Sports Phys Ther_ . 2014;44(4):A240–A248.
75\. Khayambashi K, Mohammadkhani Z, Ghaznavi K, Lyle MA, Powers CM.

The effects of isolated hip abductor and external rotator muscle
strengthening on pain, health status, and hip strength in females with
patellofemoral pain: a randomized controlled trial. _J Orthop Sports_
_Phys Ther_ . 2012;42(1):22–29.
76\. McCurdy K, Walker J, Saxe J, Woods J. The effect of short-term resis­

tance training on hip and knee kinematics during vertical drop jumps.
_J Strength Cond Res_ . 2012;26(5):1257–1264.
77\. Myer GD, Brent JL, Ford KR, Hewett TE. A pilot study to determine

the effect of trunk and hip-focused neuromuscular training on hip and
knee isokinetic strength. _Br J Sports Med_ . 2008;42(7):614–619.
78\. Dolak KL, Silkman C, Medina McKeon J, Hosey RG, Lattermann C,

Uhl TL. Hip strengthening prior to functional exercises reduces pain
sooner than quadriceps strengthening in females with patellofemoral
pain syndrome: a randomized clinical trial. _J Orthop Sports Phys Ther_ .
2011;41(8):560–570.
79\. Nakagawa TH, Muniz TB, Baldon Rde M, Dias Maciel C, de

Menezes Reiff RB, Serrao FV. The effect of additional strengthen­
ing of hip abductor and lateral rotator muscles in patellofemoral pain
syndrome: a randomized controlled pilot study. _Clin Rehabil_ . 2008;
22(12):1051–1060.
80\. Willy RW, Davis IS. The effect of a hip strengthening program on

mechanics during running and during a single leg squat. _J Orthop Sports_
_Phys Ther_ . 2011;41(9):625–632.
81\. Herman DC, Weinhold PS, Guskiewicz KM, Garrett WE, Yu B,

Padua DA. The effects of strength training on the lower extremity
biomechanics of female recreational athletes during a stop-jump task.
_Am J Sports Med_ . 2008;36(4):733–740.
82\. Willy RW, Scholz JP, Davis IS. Mirror gait retraining for the treatment

of patellofemoral pain in female runners. _Clin Biomech_ . 2012;27(10):

1045–1051.

**Dovepress**

83. Noehren B, Scholz J, Davis I. The effect of real-time gait retraining

on hip kinematics, pain and function in subjects with patellofemoral
pain syndrome. _Br J Sports Med_ . 2011;45(9):691–696.
84\. Benjaminse A, Gokeler A, Dowling AV, et al. Optimization of the

anterior cruciate ligament injury prevention paradigm: novel feedback
techniques to enhance motor learning and reduce injury risk. _J Orthop_
_Sports Phys Ther_ . 2015;45(3):170–182.
85\. Ford KR, DiCesare CA, Myer GD, Hewett TE. Real-time biofeedback

to target risk of anterior cruciate ligament injury: a technical report for
injury prevention and rehabilitation. _J Sport Rehabil_ . 2015; Techni­
cal Notes. pii: 2013-0138.
86\. Gokeler A, Benjaminse A, Hewett TE, et al. Feedback techniques to

target functional deficits following anterior cruciate ligament recon­
struction: implications for motor control and reduction of second injury
risk. _Sports Med_ . 2013;43(11):1065–1074.
87\. Wouters I, Almonroeder T, Dejarlais B, Laack A, Willson JD, Kernozek TW.

Effects of a movement training program on hip and knee joint
frontal plane running mechanics. _Int J Sports Phys Ther_ . 2012;
7(6):637–646.
88\. Freeman S, Mascia A, McGill S. Arthrogenic neuromusculature

inhibition: a foundational investigation of existence in the hip joint.
_Clin Biomech_ . 2013;28(2):171–177.
89\. Nguyen AD, Shultz SJ, Schmitz RJ. Landing biomechanics in partici­

pants with different static lower extremity alignment profiles. _J Athl_
_Train_ . 2015;50(5):498–507.
90\. Nguyen AD, Shultz SJ, Schmitz RJ, Luecht RM, Perrin DH. A pre­

liminary multifactorial approach describing the relationships among
lower extremity alignment, hip muscle activation, and lower extremity
joint excursion. _J Athl Train_ . 2011;46(3):246–256.
91\. Verrelst R, De Clercq D, Willems TM, Victor J, Witvrouw E. Contribution

of a muscle fatigue protocol to a dynamic stability screening test
for exertional medial tibial pain. _Am J Sports Med_ . 2014;42(5):

1219–1225.

92. Willson JD, Petrowitz I, Butler RJ, Kernozek TW. Male and female

gluteal muscle activity and lower extremity kinematics during running.
_Clin Biomech_ . 2012;27(10):1052–1057.
93\. Patrek MF, Kernozek TW, Willson JD, Wright GA, Doberstein ST.

Hip-abductor fatigue and single-leg landing mechanics in women
athletes. _J Athl Train_ . 2011;46(1):31–42.
94\. Kernozek TW, Torry MR, Iwasaki M. Gender differences in lower

extremity landing mechanics caused by neuromuscular fatigue. _Am J_
_Sports Med_ . 2008;36(3):554–565.
95\. Quatman-Yates CC, Myer GD, Ford KR, Hewett TE. A longitudinal

evaluation of maturational effects on lower extremity strength in
female adolescent athletes. _Pediatr Phys Ther_ . 2013;25(3):271–276.
96\. Gardinier ES, Manal K, Buchanan TS, Snyder-Mackler L. Gait and

neuromuscular asymmetries after acute anterior cruciate ligament
rupture. _Med Sci Sports Exerc_ . 2012;44(8):1490–1496.
97\. Ardern CL, Taylor NF, Feller JA, Whitehead TS, Webster KE.

Psychological responses matter in returning to preinjury level of sport
after anterior cruciate ligament reconstruction surgery. _Am J Sports_
_Med_ . 2013;41(7):1549–1558.
98\. Lentz TA, Zeppieri G Jr, George SZ, et al. Comparison of physical

impairment, functional, and psychosocial measures based on fear
of reinjury/lack of confidence and return-to-sport status after ACL
reconstruction. _Am J Sports Med_ . 2015;43(2):345–353.
99\. Paterno MV, Rauh MJ, Schmitt LC, Ford KR, Hewett TE. Incidence

of second ACL injuries 2 years after primary ACL reconstruction and
return to sport. _Am J Sports Med_ . 2014;42(7):1567–1573.
100\. Paterno MV, Rauh MJ, Schmitt LC, Ford KR, Hewett TE. Incidence

of contralateral and ipsilateral anterior cruciate ligament (ACL) injury
after primary ACL reconstruction and return to sport. _Clin J Sport_
_Med_ . 2012;22(2):116–121.

**302**

**submit your manuscript** | \<www.dovepress.com> Open Access Journal of Sports Medicine 2015:6

**Dovepress**

**Dovepress**

**Open Access Journal of Sports Medicine**

**Publish your work in this journal**

Open Access Journal of Sports Medicine is an international,
peer-reviewed, open access journal publishing original research,
reports, reviews and commentaries on all areas of sports
medicine. The manuscript management system is completely
online and includes a very quick and fair peer-review system.

Hip-focused neuromuscular exercise for dynamic lower extremity valgus

**Dovepress**

[Visit http://www.dovepress.com/testimonials.php to read real quotes](http://www.dovepress.com/testimonials.php)
from published authors.

**Submit your manuscript here:** [http://www.dovepress.com/open-access-journal-of-sports-medicine-journal](http://www.dovepress.com/open-access-journal-of-sports-medicine-journal)

Open Access Journal of Sports Medicine 2015:6 **submit your manuscript** | \<www.dovepress.com>

**Dovepress**

**303**
